'''
-----------------------------------------------------------------------------
 Symmetric two dimensional model of a single edged notch specimen
 modeled using reduced integration plane stress elements (CPE8R).
 
 Fracture analysis is done on this model subjected to thermal stresses
 obtained by running a Heat transfer analysis on this model.
 
 Submit the job: SingleEdThermMesh1CPE8R
-----------------------------------------------------------------------------
'''

from abaqus import *
from abaqusConstants import *

import part, material, section, assembly, step, interaction
import regionToolset, displayGroupMdbToolset as dgm, mesh
import load, job

#----------------------------------------------------------------------------

# Open the CAE model and create a viewport for viewing it.

Mdb()
modelName = 'SingleEdThermMesh1CPS8R'
openMdb(modelName)
myModel = mdb.models[modelName]
myAssembly = myModel.rootAssembly
myViewport = session.Viewport(name=modelName)
myViewport.makeCurrent()
myViewport.maximize()
myViewport.setValues(displayedObject=myAssembly)

#---------------------------------------------------------------------------

# Submit the job for analysis

mdb.jobs[modelName].submit()
mdb.jobs[modelName].waitForCompletion()

#---------------------------------------------------------------------------
